Features:

- Scrapes the HTML from https://eztv.it/
- Offers a simple API to get a list of shows and episodes for TV seasons
- Has unit tests, and tests that that run against the live website

See https://github.com/jaysh/eztvit-python for build status.